==> question2answer-1.5-language-lt.zip: lt/qa-lang-misc.php <==
<?php
	
/*
	Question2Answer (c) Gideon Greenspan

	http://www.question2answer.org/

	
	File: qa-include/qa-lang-misc.php
	Version: See define()s at top of qa-include/qa-base.php
	Description: Miscellaneous language phrases


	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 2
	of the License, or (at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	More about this license: http://www.question2answer.org/license.php
*/

	return array(
		'block_ip_button' => 'Blokuoti IP adresą',
		'browse_categories' => 'Naršyti kategorijas',
		'captcha_confirm_fix' => 'Tam kad išvengti šio patikrinimo ateityje, prašom ^5patvirtinti savo el. pašto adresą^6.',
		'captcha_error' => 'Prašom atlikti patikrinimą nuo brukalų',
		'captcha_label' => 'Patikrinimas nuo brukalų:',
		'captcha_login_fix' => 'Tam kad išvengti šio patikrinimo ateityje, prašom ^1prisijungti^2 arba ^3prisiregistruoti^4.',
		'feed_a_edited_prefix' => 'Atsakymas redaguotas: ',
		'feed_a_prefix' => 'Atsakyta: ',
		'feed_a_reshown_prefix' => 'Atsakymas vėl parodytas: ',
		'feed_a_selected_prefix' => 'Atsakymas pasirinktas: ',
		'feed_c_edited_prefix' => 'Komentaras redaguotas: ',
		'feed_c_moved_prefix' => 'Komentaras perkeltas: ',
		'feed_c_prefix' => 'Kuomentuota: ',
		'feed_c_reshown_prefix' => 'Komentaras vėl parodytas: ',
		'feed_closed_prefix' => 'Uždaryta: ',
		'feed_edited_prefix' => 'Redaguota: ',
		'feed_hidden_prefix' => 'Paslėpta: ',
		'feed_not_found' => 'RSS nerastas',
		'feed_recategorized_prefix' => 'Pakeista kategorija: ',
		'feed_reopened_prefix' => 'Vėl atidaryta: ',
		'feed_reshown_prefix' => 'Vėl parodyta: ',
		'feed_retagged_prefix' => 'Pakeistos žymės: ',
		'feedback_email' => 'Jūsų el. paštas: (neprivaloma)',
		'feedback_empty' => 'Prašom įrašyti komentarus ar pasiūlymus',
		'feedback_message' => 'Jūsų komentarai ar pasiūlymai dėl ^:',
		'feedback_name' => 'Jūsų vardas: (neprivaloma)',
		'feedback_sent' => 'Jūsų žinutė buvo išsiųsta - dėkojame.',
		'feedback_title' => 'Siųsti atsiliepimą',
		'hide_all_ip_button' => 'Paslėpti visus įrašus iš šio IP adreso',
		'host_name' => 'Serverio adresas:',
		'matches_blocked_ips' => 'Atitinka blokuotus IP adresus:',
		'message_empty' => 'Prašom įvesti žinutę siunčiamą šiam vartotojui',
		'message_explanation' => 'Tai bus išsiųsta kaip pranešimas nuo ^. Jūsų el. pašto adresas nebus parodytas, nebent jūs jį įtrauksite į žinutės turinį.',
		'message_for_x' => 'Jūsų žinutė dėl ^:',
		'message_limit' => 'Išsiųsta per daug privačių žinučių - prašom pabandyti už valandos',
		'message_must_login' => 'Prašom ^1prisijungti^2 arba ^3prisiregistruoti^4 tam, kad galėtumėte siųsti privačias žinutes.',
		'message_received_x_ago' => 'Gauta prieš ^:',
		'message_recent_history' => 'Naujausias susirašinėjimas su ^',
		'message_sent_x_ago' => 'Išsiųsta prieš ^:',
		'message_sent' => 'Privati žinutė buvo išsiųsta',
		'my_favorites_title' => 'Mano mėgstamiausi',
		'nav_all_my_updates' => 'Visi mano atnaujinimai',
		'nav_my_content' => 'Mano turinys',
		'nav_my_details' => 'Mano detalės',
		'nav_my_favorites' => 'Mano mėgstamiausi',
		'no_activity_from_x' => 'Nėra veiklos nuo ^',
		'no_favorite_categories' => 'Nėra mėgstamiausių kategorijų',
		'no_favorite_qs' => 'Nėra mėgstamiausių klausimų',
		'no_favorite_tags' => 'Nėra mėgstamiausių žymių',
		'no_favorite_users' => 'Nėra mėgstamiausių vartotojų',
		'no_recent_updates' => 'Nėra naujausių atnaujinimų',
		'no_updates_content' => 'Nėra naujausių atnaujinimų mano turiniui',
		'no_updates_favorites' => 'Nėra atnaujinimų mano mėgstamiausiems',
		'private_message_title' => 'Siųsti privačią žinutę',
		'recent_activity_from_x' => 'Naujausia veikla iš ^',
		'recent_updates_content' => 'Naujausi atnaujinimai mano turiniui',
		'recent_updates_favorites' => 'Naujausi atnaujinimai mano mėgstamiausiems',
		'recent_updates_title' => 'Naujausi mano atnaujinimai',
		'site_in_maintenance' => 'Ši svetainė šiuo metu yra sustabdyta atnaujinimo darbams - prašom apsilankyti vėliau.',
		'suggest_favorites_add' => 'Tam, kad pridėtumėte klausimą ar kitą įrašą prie savo mėgstamiausių, paspauskite ^ šio puslapio viršuje.',
		'suggest_update_favorites' => 'Kad gautumėte daugiau atnaujinimų, pridėkite įrašus prie ^1savo mėgstamiausių^2.',
		'unblock_ip_button' => 'Atblokuoti IP adresą',
	);
	

/*
	Omit PHP closing tag to help avoid accidental output
*/

==> question2answer-1.7-language-lt.zip: lt/qa-lang-misc.php <==
<?php
/*
	Question2Answer by Gideon Greenspan and contributors
	http://www.question2answer.org/

	File: qa-include/qa-lang-misc.php
	Description: Miscellaneous language phrases


	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 2
	of the License, or (at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	More about this license: http://www.question2answer.org/license.php
*/

	return array(
		'block_ip_button' => 'Blokuoti IP adresą',
		'browse_categories' => 'Naršyti kategorijas',
		'captcha_approve_fix' => 'Šis patikrinimas nebebus rodomas, kai jūsų paskyra bus patvirtinta.',
		'captcha_confirm_fix' => 'Tam kad išvengti šio patikrinimo ateityje, prašom ^5patvirtinti savo el. pašto adresą^6.',
		'captcha_error' => 'Prašom atlikti patikrinimą nuo brukalų',
		'captcha_label' => 'Patikrinimas nuo brukalų:',
		'captcha_login_fix' => 'Tam kad išvengti šio patikrinimo ateityje, prašom ^1prisijungti^2 arba ^3prisiregistruoti^4.',
		'feed_a_edited_prefix' => 'Atsakymas redaguotas: ',
		'feed_a_prefix' => 'Atsakyta: ',
		'feed_a_reshown_prefix' => 'Atsakymas vėl parodytas: ',
		'feed_a_selected_prefix' => 'Atsakymas pasirinktas: ',
		'feed_c_edited_prefix' => 'Komentaras redaguotas: ',
		'feed_c_moved_prefix' => 'Komentaras perkeltas: ',
		'feed_c_prefix' => 'Kuomentuota: ',
		'feed_c_reshown_prefix' => 'Komentaras vėl parodytas: ',
		'feed_closed_prefix' => 'Uždaryta: ',
		'feed_edited_prefix' => 'Redaguota: ',
		'feed_hidden_prefix' => 'Paslėpta: ',
		'feed_not_found' => 'RSS nerastas',
		'feed_recategorized_prefix' => 'Pakeista kategorija: ',
		'feed_reopened_prefix' => 'Vėl atidaryta: ',
		'feed_reshown_prefix' => 'Vėl parodyta: ',
		'feed_retagged_prefix' => 'Pakeistos žymės: ',
		'feedback_email' => 'Jūsų el. paštas: (neprivaloma)',
		'feedback_empty' => 'Prašom įrašyti komentarus ar pasiūlymus',
		'feedback_message' => 'Jūsų komentarai ar pasiūlymai dėl ^:',
		'feedback_name' => 'Jūsų vardas: (neprivaloma)',
		'feedback_sent' => 'Jūsų žinutė buvo išsiųsta - dėkojame.',
		'feedback_title' => 'Siųsti atsiliepimą',
		'form_security_again' => 'Prašome paspausti dar kartą, kad patvirtintumėte',
		'form_security_reload' => 'Prašome atnaujinti šį puslapį ir tada pabandyti iš naujo',
		'hide_all_ip_button' => 'Paslėpti visus įrašus iš šio IP adreso',
		'host_name' => 'Serverio adresas:',
		'inbox' => 'Gauti',
		'matches_blocked_ips' => 'Atitinka blokuotus IP adresus:',
		'message_empty' => 'Prašom įvesti žinutę siunčiamą šiam vartotojui',
		'message_explanation' => 'Tai bus išsiųsta kaip pranešimas nuo ^. Jūsų el. pašto adresas nebus parodytas, nebent jūs jį įtrauksite į žinutės turinį.',
		'message_for_x' => 'Jūsų žinutė dėl ^:',
		'message_limit' => 'Išsiųsta per daug privačių žinučių - prašom pabandyti už valandos',
		'message_must_login' => 'Prašom ^1prisijungti^2 arba ^3prisiregistruoti^4 tam, kad galėtumėte siųsti privačias žinutes.',
		'message_recent_history' => 'Naujausias susirašinėjimas su ^',
		'message_sent' => 'Privati žinutė buvo išsiųsta',
		'more_favorite_qs' => 'Daugiau mėgstamiausių questions...',
		'more_favorite_tags' => 'Daugiau mėgstamiausių žymių...',
		'more_favorite_users' => 'Daugiau mėgstamiausių vartotojų...',
		'my_favorites_title' => 'Mano mėgstamiausi',
		'nav_all_my_updates' => 'Visi mano atnaujinimai',
		'nav_my_content' => 'Mano turinys',
		'nav_my_details' => 'Mano detalės',
		'nav_my_favorites' => 'Mano mėgstamiausi',
		'nav_user_activity' => 'Naujausia veikla',
		'nav_user_as' => 'Visi atsakymai',
		'nav_user_pms' => 'Privačios žinutės',
		'nav_user_qs' => 'Visi klausimai',
		'nav_user_wall' => 'Siena',
		'no_activity_from_x' => 'Nėra veiklos nuo ^',
		'no_favorite_categories' => 'Nėra mėgstamiausių kategorijų',
		'no_favorite_qs' => 'Nėra mėgstamiausių klausimų',
		'no_favorite_tags' => 'Nėra mėgstamiausių žymių',
		'no_favorite_users' => 'Nėra mėgstamiausių vartotojų',
		'no_recent_updates' => 'Nėra naujausių atnaujinimų',
		'no_updates_content' => 'Nėra naujausių atnaujinimų mano turiniui',
		'no_updates_favorites' => 'Nėra atnaujinimų mano mėgstamiausiems',
		'outbox' => 'Išsiųsti',
		'pm_inbox_title' => 'Gautos privačios žinutės',
		'pm_outbox_title' => 'Išsiųstos privačios žinutės',
		'private_message_title' => 'Siųsti privačią žinutę',
		'recent_activity_from_x' => 'Naujausia veikla iš ^',
		'recent_updates_content' => 'Naujausi atnaujinimai mano turiniui',
		'recent_updates_favorites' => 'Naujausi atnaujinimai mano mėgstamiausiems',
		'recent_updates_title' => 'Naujausi mano atnaujinimai',
		'site_in_maintenance' => 'Ši svetainė šiuo metu yra sustabdyta atnaujinimo darbams - prašom apsilankyti vėliau.',
		'suggest_favorites_add' => 'Tam, kad pridėtumėte klausimą ar kitą įrašą prie savo mėgstamiausių, paspauskite ^ šio puslapio viršuje.',
		'suggest_update_favorites' => 'Kad gautumėte daugiau atnaujinimų, pridėkite įrašus prie ^1savo mėgstamiausių^2.',
		'unblock_ip_button' => 'Atblokuoti IP adresą',
		'your_a_commented' => 'jūsų atsakymas pakomentuotas',
		'your_a_edited' => 'jūsų atsakymas paredaguotas',
		'your_a_hidden' => 'jūsų atsakymas paslėptas',
		'your_a_questioned' => 'paklausta naudojantis jūsų klausimu',
		'your_a_reshown' => 'jūsų atsakymas vėl parodytas',
		'your_a_selected' => 'jūsų atsakymas pasirinktas',
		'your_c_edited' => 'jūsų komentaras paredaguotas',
		'your_c_followed' => 'jūsų komentaras imtas sekti',
		'your_c_hidden' => 'jūsų komentaras paslėptas',
		'your_c_moved' => 'jūsų komentaras perkeltas',
		'your_c_reshown' => 'jūsų komentaras vėl parodytas',
		'your_q_answered' => 'jūsų klausimas atsakytas',
		'your_q_closed' => 'jūsų klausimas uždarytas',
		'your_q_commented' => 'jūsų klausimas pakomentuotas',
		'your_q_edited' => 'jūsų klausimas paredaguotas',
		'your_q_hidden' => 'jūsų klausimas paslėptas',
		'your_q_recategorized' => 'jūsų klausimas perkategorizuotas',
		'your_q_reopened' => 'jūsų klausimas vėl atidarytas',
		'your_q_reshown' => 'jūsų klausimas vėl parodytas',
		'your_q_retagged' => 'jūsų klausimas iš naujo sužymėtas',
	);
	

/*
	Omit PHP closing tag to help avoid accidental output
*/
